@@ -1,4 +1,4 @@
-# Copyright 2004-2021 Bright Computing Holding BV
+# Copyright 2004-2022 Bright Computing Holding BV
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -73,6 +73,7 @@ WLMS_8_2 = [
     "sge",
     "pbspro",
     "pbspro-ce",
+    "openpbs",
     # LSF and UGE are supported by Bright, but not ouf of the box
 ]
 
@@ -163,6 +164,7 @@ common_ns.add_switch_parameter(
     help="Show this message and exit")
 common_ns.add_switch_parameter(
     "advanced_help",
+    flags=["-H"],
     help="Don't omit advanced configuration parameters from the help output. Implies --help")
 common_ns.add_parameter(
     "explain",
@@ -174,6 +176,10 @@ common_ns.add_switch_parameter(
     "verbose",
     flags=["-v", "-vv", "-vvv"],
     help="Verbosity level")
+common_ns.add_switch_parameter(
+    "print_stack_trace_on_failure",
+    default=False,
+    help="Print the stack trace on failure, even if -v wasn't specified")
 common_ns.add_parameter(
     "log_file",
     advanced=True,
