@@ -1,4 +1,4 @@
-# Copyright 2004-2021 Bright Computing Holding BV
+# Copyright 2004-2022 Bright Computing Holding BV
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -62,9 +62,8 @@ class CODImage:
     uuid: str = ""
     version: str = ""
     package_groups: list = field(default_factory=list)
-    cmd_hash: str = ""
-    cm_setup_hash: str = ""
-    cluster_tools_hash: str = ""
+    pkg_hashes: list = field(default_factory=list)
+    bcm_api_hash: str = ""
     node_images: list = field(default_factory=list)
 
     @staticmethod
@@ -101,13 +100,14 @@ class CODImage:
             name=CODImage.image_name(image.image_type(), image.id(), image.revision()),
             image_visibility="public",
             revision=image.revision(),
-            size=image.size(),
+            size=image.uncompressed_size(),
             tags=image.tags(),
             type=image.image_type(),
             uploaded_at=datetime.fromtimestamp(image.created_at(), pytz.utc),
             uuid="N/A",
             version=str(image.bcm_version()),
             package_groups=sorted(image.package_groups()),
+            bcm_api_hash=image.bcm_api_hash(),
         )
 
     @classmethod
@@ -127,11 +127,8 @@ class CODImage:
         """
         return {
             "bcm_cloud_type": self.cloud_type,
-            "bcm_cluster_tools_hash": self.cluster_tools_hash,
-            "bcm_cmd_hash": self.cmd_hash,
             "bcm_cmd_revision": str(self.cmd_revision),
-            "bcm_cm_setup_hash": self.cm_setup_hash,
-            "bcm_created_at": str(self.created_at),
+            "bcm_created_at": self.created_at.isoformat(),
             "bcm_distro": self.distro,
             "bcm_distro_family": self.distro_family,
             "bcm_image_id": self.id,
@@ -139,7 +136,9 @@ class CODImage:
             "bcm_image_type": self.type,
             "bcm_optional_info": self.bcm_optional_info,
             "bcm_package_groups": ",".join(self.package_groups),
+            "bcm_pkg_hashes": ",".join(f"{pkg}={git_hash}" for pkg, git_hash in self.pkg_hashes),
             "bcm_version": str(self.version),
+            "bcm_api_hash": str(self.bcm_api_hash),
         }
 
     def get_tags(self):
@@ -356,8 +355,30 @@ class ImageSource:
 
     @classmethod
     def _pick_head_node_image_by_opts(cls, opts):
-        source = cls.from_config(opts, ids=["*"])
-        images = list(source.find_images(latest=True))
+        """
+        Pick the head node image, based on the configuration (opts)
+        Image distribution is decided based on the configuration parameters: distro and distro_default. They can be
+        specified from the cli or configuration file, E.g. krusty.ini
+        Decision logic:
+        default_distro  distro
+        Y               Y           use distro
+        Y               N           iterate over default_distro, use the first distro for which image is found
+        N               Y           use distro
+        N               N           get images without filtering them by distribution and use the latest one
+        :param opts: config
+        :return: CODImage
+        """
+        if opts["distro_default"] and not opts["distro"]:
+            for distro in opts["distro_default"]:
+                log.debug(f"Searching for an image for {distro} from distro_default list")
+                opts["distro"] = distro
+                source = cls.from_config(opts, ids=["*"])
+                images = list(source.find_images(latest=True))
+                if images:
+                    break
+        else:
+            source = cls.from_config(opts, ids=["*"])
+            images = list(source.find_images(latest=True))
 
         selected_distro = latest_distro([i.distro for i in images], opts["distro"])
         images = [i for i in images if i.distro == selected_distro]
@@ -548,6 +569,14 @@ findimages_ns.add_parameter(
     help=("(default: all distros) show only images from this distro."
           "This is a regex")
 )
+findimages_ns.add_enumeration_parameter(
+    "distro_default",
+    default=[],
+    help="List of distributions. If the user didn't explicitly specify a distro, "
+         "iterate over this list and use the first distribution, for which the image is found. "
+         "Ignored if combined with --distro. "
+         "Each list element is a regex"
+)
 findimages_ns.add_parameter(
     "revision",
     type=int,
